==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.chronos/src/com/openexchange/chronos/Repeat.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;

/**
 * {@link Repeat}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 * @see <a href="https://tools.ietf.org/html/rfc5545#section-3.8.6.2">RFC 5545, section 3.8.6.2</a>
 */
public class Repeat {

	private String duration;
    private int count;

    /**
     * Initializes a new {@link Repeat}.
     */
    public Repeat() {
        super();
    }

    /**
     * Initializes a new {@link Repeat}.
     *
     * @param count The number of additional repetitions the alarm will be triggered
     * @param duration The delay period after which the alarm will repeat
     */
    public Repeat(int count, String duration) {
        super();
        this.count = count;
        this.duration = duration;
    }

    /**
     * Gets the number of additional repetitions the alarm will be triggered. *
     *
     * @return The repetition count
     */
    public int getCount() {
        return count;
    }

    /**
     * Gets the delay period after which the alarm will repeat.
     *
     * @return The delay period
     */
    public String getDuration() {
        return duration;
    }

    @Override
    public String toString() {
        return "Repeat [count=" + count + ", duration=" + duration + "]";
    }

}

==> open-xchange-core_7.10.3.orig.tar.bz2: open-xchange-core-7.10.3/com.openexchange.chronos/src/com/openexchange/chronos/Repeat.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;

/**
 * {@link Repeat}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 * @see <a href="https://tools.ietf.org/html/rfc5545#section-3.8.6.2">RFC 5545, section 3.8.6.2</a>
 */
public class Repeat {

    private String duration;
    private int count;

    /**
     * Initializes a new {@link Repeat}.
     */
    public Repeat() {
        super();
    }

    /**
     * Initializes a new {@link Repeat}.
     *
     * @param count The number of additional repetitions the alarm will be triggered
     * @param duration The delay period after which the alarm will repeat
     */
    public Repeat(int count, String duration) {
        super();
        this.count = count;
        this.duration = duration;
    }

    /**
     * Gets the number of additional repetitions the alarm will be triggered. *
     *
     * @return The repetition count
     */
    public int getCount() {
        return count;
    }

    /**
     * Gets the delay period after which the alarm will repeat.
     *
     * @return The delay period
     */
    public String getDuration() {
        return duration;
    }

    @Override
    public String toString() {
        return "Repeat [count=" + count + ", duration=" + duration + "]";
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + count;
        result = prime * result + ((duration == null) ? 0 : duration.hashCode());
        return result;
    }

}
